@@ -905,6 +905,7 @@ class RoomEncryptedMedia(RoomMessage):
         hashes (dict): A mapping from an algorithm name to a hash of the
             ciphertext encoded as base64.
         iv (str): The initialisation vector that was used to encrypt the file.
+        mimetype (str): The mimetype of the message.
 
         thumbnail_url (str, optional): The URL of the thumbnail file.
         thumbnail_key (dict, optional): The key that can be used to decrypt the
@@ -920,6 +921,7 @@ class RoomEncryptedMedia(RoomMessage):
     key: Dict[str, Any] = field()
     hashes: Dict[str, Any] = field()
     iv: str = field()
+    mimetype: str = field()
 
     thumbnail_url: Optional[str] = None
     thumbnail_key: Optional[Dict] = None
@@ -944,6 +946,7 @@ class RoomEncryptedMedia(RoomMessage):
             parsed_dict["content"]["file"]["key"],
             parsed_dict["content"]["file"]["hashes"],
             parsed_dict["content"]["file"]["iv"],
+            parsed_dict["content"]["file"]["mimetype"],
             thumbnail_url,
             thumbnail_key,
             thumbnail_hashes,
